package com.example.wholeestate.controller;


import com.example.wholeestate.common.base.BaseController;
import com.example.wholeestate.common.resp.ResponseBean;
import com.example.wholeestate.service.IAppointmentService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
 * 预约记录表 前端控制器
 * </p>
 *
 * @author jobob
 * @since 2019-03-21
 */
@RestController
@RequestMapping("/")
@Api(value = "预约记录 API", description = "预约记录 API")
public class AppointmentController extends BaseController {

    @Autowired
    private IAppointmentService iAppointmentService;

    @RequestMapping(value = "/wx/appointment/{openid}", method = RequestMethod.GET)
    @ApiOperation(value = "微信小程序 根据openid 查询 预约记录", notes = "根据openid 查询 预约记录")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "query", dataTypeClass = Integer.class, name = "pageNum", value = "pageNum第几页"),
            @ApiImplicitParam(paramType = "query", dataTypeClass = Integer.class, name = "pageSize", value = "pageSize一页多少行"),
            @ApiImplicitParam(paramType = "path", dataTypeClass = String.class, name = "openid", value = "openid")
    })
    public ResponseBean openidAppointementList(@PathVariable("openid") String openid, @RequestParam(defaultValue = "1") Integer pageNum, @RequestParam(defaultValue = "10") Integer pageSize) {
        ResponseBean responseBean = new ResponseBean();
        responseBean = iAppointmentService.getOpenidAppointmentList(openid, pageNum, pageSize);
        return responseBean;
    }

    @RequestMapping(value = "/wx/appointment/{openid}", method = RequestMethod.POST)
    @ApiOperation(value = "微信小程序 根据openid 添加 预约记录", notes = "根据openid 添加 预约记录")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", dataTypeClass = String.class, name = "parameter", value = "buildingId楼盘编号;appointmentDate预约时间;customerName姓名;phone手机;remark备注"),
            @ApiImplicitParam(paramType = "path", dataTypeClass = String.class, name = "openid", value = "openid")
    })
    public ResponseBean openidAppointementList(@PathVariable("openid") String openid, @RequestBody String parameter) {
        ResponseBean responseBean = new ResponseBean();
        responseBean = iAppointmentService.addWxAppointment(openid, parameter);
        return responseBean;
    }

    @RequestMapping(value = "/wx/appointment/of/{appointmentId}", method = RequestMethod.DELETE)
    @ApiOperation(value = "微信小程序 删除预约记录", notes = "微信小程序 删除预约记录")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataTypeClass = String.class, name = "appointmentId", value = "预约ID")
    })
    public ResponseBean wxDelete(@PathVariable("appointmentId") String appointmentId) {
        return iAppointmentService.deleteWxAppointment(appointmentId);
    }

}
