package com.example.wholeestate.controller;


import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.example.wholeestate.common.base.BaseController;
import com.example.wholeestate.common.resp.ResponseBean;
import com.example.wholeestate.common.uuid.IdGen;
import com.example.wholeestate.model.Activity;
import com.example.wholeestate.model.BuildingDynamic;
import com.example.wholeestate.model.PageImg;
import com.example.wholeestate.service.IBuildingDynamicService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.beans.propertyeditors.CustomDateEditor;
import org.springframework.web.bind.ServletRequestDataBinder;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.util.Date;
import java.util.HashMap;

/**
 * <p>
 * 项目动态表 前端控制器
 * </p>
 *
 * @author jobob
 * @since 2019-03-21
 */
@RestController
@RequestMapping("/")
@Api(value = "项目动态管理API",description = "项目动态管理API")
public class BuildingDynamicController extends BaseController {

    @Autowired
    private IBuildingDynamicService iBuildingDynamicService;
    private IdGen idGen = IdGen.get();

    @InitBinder
    protected void initBinder(HttpServletRequest request, ServletRequestDataBinder binder) throws Exception {
        DateFormat df = new SimpleDateFormat("yyyy-MM-dd");
        CustomDateEditor editor = new CustomDateEditor(df, true);//true表示允许为空，false反之
        binder.registerCustomEditor(Date.class, editor);
    }

    @ApiOperation(value = "项目动态管理列表", notes = "项目动态管理列表")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "Query",dataType = "Integer",name = "pageNum",value = "分页第几页" ),
            @ApiImplicitParam(paramType = "Query",dataType = "Integer",name = "pageSize",value = "pageSize:每页长度"),
            @ApiImplicitParam(paramType = "Query",dataType = "string",name = "name",value = "name:动态标题"),
            @ApiImplicitParam(paramType = "Query",dataType = "string",name = "buildingId",value = "buildingId:楼盘id")
    })
    @RequestMapping(value = "/iBuildingDynamicList", method = RequestMethod.GET)
    public ResponseBean iBuildingDynamicList(@RequestParam("pageNum")Integer pageNum,
                                             @RequestParam("pageSize")Integer pageSize,
                                             @RequestParam(required = false)String name ,
                                             @RequestParam(required = false)String buildingId,
                                             HttpSession session){
        ResponseBean  responseBean = iBuildingDynamicService.iBuildingDynamicList(pageNum,pageSize,name,buildingId);
        return responseBean;
    }

    @RequestMapping(value = "/iBuildingDynamicSelectId/{id}", method = RequestMethod.GET)
    @ApiOperation(value = "项目动态详情", notes = "项目动态详情")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataTypeClass=String.class, name = "id", value = "项目动态id"),
    })
    public ResponseBean iBuildingDynamicSelectId(@PathVariable(value = "id") String id, HttpSession session){
        ResponseBean  responseBean = iBuildingDynamicService.iBuildingDynamicSelectId(id);
        return responseBean;
    }

    @ApiOperation(value = "微信小程序端项目动态管理列表", notes = "微信小程序端项目动态管理列表")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "Query",dataType = "Integer",name = "pageNum",value = "分页第几页" ),
            @ApiImplicitParam(paramType = "Query",dataType = "Integer",name = "pageSize",value = "pageSize:每页长度")

    })
    @RequestMapping(value = "/wx/buildingDynamiceList", method = RequestMethod.GET)
    public ResponseBean wxBuildingDynamiceList(@RequestParam("pageNum")Integer pageNum,@RequestParam("pageSize")Integer pageSize, HttpSession session){
        ResponseBean  responseBean = iBuildingDynamicService.getWxBuildingDynamiceList(pageNum,pageSize);
        return responseBean;
    }

    @RequestMapping(value = "/wx/buildingDynamiceInfo/{dynamicId}", method = RequestMethod.GET)
    @ApiOperation(value = "微信小程序项目动态详情", notes = "微信小程序项目动态详情")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataTypeClass=String.class, name = "dynamicId", value = "项目动态dynamicId"),
    })
    public ResponseBean iBuildingDynamicInfo(@PathVariable(value = "dynamicId") String dynamicId, HttpSession session){
        ResponseBean  responseBean = iBuildingDynamicService.getWxBuildingDynamiceInfo(dynamicId);
        return responseBean;
    }

    @RequestMapping(value = "/buildingDynamic/add" ,method =RequestMethod.POST)
    @ApiOperation(value = "动态管理添加",notes="动态管理添加")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", dataTypeClass = String.class, name = "parameter", value = "buildingId楼盘id;imgUrl首页图片;title标题;desc描述;url:链接地址")
    })
    public  ResponseBean buildingDynamicAdd(@RequestBody String parameter){
        ResponseBean responseBean = new ResponseBean();
        BuildingDynamic dynamic = JSONObject.parseObject(parameter, BuildingDynamic.class);
        dynamic.setStatus(0);
        dynamic.setDynamicId(idGen.nextId()+"");
        dynamic.setCreateDate(LocalDateTime.now());
        iBuildingDynamicService.save(dynamic);
        return responseBean;
    }

    @RequestMapping(value = "/buildingDynamic/update" ,method =RequestMethod.PUT)
    @ApiOperation(value = "动态管理修改",notes="动态管理修改")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", dataTypeClass = String.class, name = "parameter", value = "dynamicId主键;buildingId楼盘id;imgUrl首页图片;title标题;desc描述;url:链接地址")
    })
    public  ResponseBean buildingDynamicUpdate(@RequestBody String parameter){
        ResponseBean responseBean = new ResponseBean();
        BuildingDynamic dynamic = JSONObject.parseObject(parameter, BuildingDynamic.class);
        QueryWrapper<BuildingDynamic> buildingDynamicQueryWrapper = new QueryWrapper<>();
        buildingDynamicQueryWrapper.eq("dynamic_id", dynamic.getDynamicId());
        iBuildingDynamicService.update(dynamic, buildingDynamicQueryWrapper);
        return responseBean;
    }

    @ApiOperation(value = "项目动态删除", notes = "项目动态删除")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "Query",dataType = "String",name = "id",value = "id" ),
    })
    @RequestMapping(value = "/buildingDynamic/delete", method = RequestMethod.DELETE)
    public ResponseBean pageImdelect(@RequestParam(value = "id",required = false)String id) {
        ResponseBean responseBean = iBuildingDynamicService.buildingDynamicDelete(id);
        return responseBean;
    }

    @RequestMapping(value = "/buildingDynamic/send/{dynamicId}", method = RequestMethod.PUT)
    @ApiOperation(value = "项目动态发布", notes = "项目动态发布")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataTypeClass = String.class, name = "dynamicId", value = "dynamicId主键")
    })
    public ResponseBean send(@PathVariable String dynamicId) {
        ResponseBean responseBean = new ResponseBean();
        QueryWrapper<BuildingDynamic> dynamicQueryWrapper = new QueryWrapper<>();
        dynamicQueryWrapper.eq("dynamic_id", dynamicId);
        BuildingDynamic dynamic = iBuildingDynamicService.getOne(dynamicQueryWrapper);
        dynamic.setStatus(1);
        dynamic.setPublishDate(LocalDateTime.now());
        iBuildingDynamicService.update(dynamic, dynamicQueryWrapper);
        return responseBean;
    }

    @RequestMapping(value = "/buildingDynamic/cancel/{dynamicId}", method = RequestMethod.PUT)
    @ApiOperation(value = "项目动态取消发布", notes = "项目动态取消发布")
    public ResponseBean cancel(@PathVariable String dynamicId) {
        ResponseBean responseBean = new ResponseBean();
        QueryWrapper<BuildingDynamic> dynamicQueryWrapper = new QueryWrapper<>();
        dynamicQueryWrapper.eq("dynamic_id", dynamicId);
        BuildingDynamic dynamic = iBuildingDynamicService.getOne(dynamicQueryWrapper);
        dynamic.setStatus(0);
        iBuildingDynamicService.update(dynamic, dynamicQueryWrapper);
        return responseBean;
    }
}
