package com.example.wholeestate.controller;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.example.wholeestate.common.base.BaseController;
import com.example.wholeestate.common.resp.ResponseBean;
import com.example.wholeestate.model.Comment;
import com.example.wholeestate.service.ICommentService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.propertyeditors.CustomDateEditor;
import org.springframework.web.bind.ServletRequestDataBinder;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * <p>
 * 评论表 前端控制器
 * </p>
 *
 * @author weiximei
 * @since 2019-03-20
 */
@RestController
@RequestMapping("/")
@Api(value = "评论 API", description = "评论 API")
public class CommentController extends BaseController {

    @Autowired
    private ICommentService iCommentService;

    @InitBinder
    protected void initBinder(HttpServletRequest request, ServletRequestDataBinder binder) throws Exception {
        DateFormat df = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        CustomDateEditor editor = new CustomDateEditor(df, true);//true表示允许为空，false反之
        binder.registerCustomEditor(Date.class, editor);
    }
    @RequestMapping(value = "/comment/delete/{commentId}", method = RequestMethod.DELETE)
    @ApiOperation(value = "删除评论", notes = "删除评论")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataTypeClass = String.class, name = "commentId",value = "评论编号")
    })
    public ResponseBean delete(@PathVariable("commentId") String commentId) {
        ResponseBean responseBean = new ResponseBean();
        QueryWrapper<Comment> commentQueryWrapper = new QueryWrapper<>();
        commentQueryWrapper.eq("comment_id", commentId);
        Comment comment = iCommentService.getOne(commentQueryWrapper);
        if (null == comment) {
            responseBean.addError("评论不存在!");
            return responseBean;
        }

        comment.setStatus(-1);
        iCommentService.update(comment,commentQueryWrapper);

        // 删除这个评论下的子评论
        Comment  childComment = new Comment();
        childComment.setStatus(-1);
        QueryWrapper<Comment> childCommentQueryWrapper = new QueryWrapper<>();
        childCommentQueryWrapper.eq("parent_id", commentId);
        iCommentService.update(childComment, childCommentQueryWrapper);
        responseBean.addSuccess("操作成功!");
        return responseBean;
    }

    @RequestMapping(value = "/comment/add", method = RequestMethod.POST)
    @ApiOperation(value = "添加评论", notes = "添加评论")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", dataTypeClass = String.class, name = "parameter", value = "customerId用户ID;commentType评论类型;mainId评论类型;parentId父级;commentContent评论内容;imgArray图片URL数组")
    })
    public ResponseBean addComment(@RequestBody String parameter) {
        ResponseBean responseBean = new ResponseBean();
        responseBean = iCommentService.addComment(parameter);
        return responseBean;
    }


    @RequestMapping(value = "/comment/list", method = RequestMethod.GET)
    @ApiOperation(value = "查询评论列表", notes = "查询评论列表")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "query", dataTypeClass = Integer.class, name = "pageNum", value = "pageNum第几页"),
            @ApiImplicitParam(paramType = "query", dataTypeClass = Integer.class, name = "pageSize", value = "pageSize一页多少行"),
            @ApiImplicitParam(paramType = "query", dataTypeClass = String.class, name = "commentType", value = "评论类型"),
            @ApiImplicitParam(paramType = "query", dataTypeClass = String.class, name = "mainId", value = "评论主体id"),
    })
    public ResponseBean commentList(@RequestParam(defaultValue = "1") Integer pageNum,
                                    @RequestParam(defaultValue = "10") Integer pageSize,
                                    @RequestParam String commentType,
                                    @RequestParam(required = false) String mainId) {
        ResponseBean responseBean = new ResponseBean();
        responseBean = iCommentService.getCommentList(commentType, mainId, pageNum, pageSize);
        return responseBean;
    }

    @RequestMapping(value = "/wx/comment/list", method = RequestMethod.GET)
    @ApiOperation(value = "微信小程序查询评论列表", notes = "微信小程序查询评论列表")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "query", dataTypeClass = Integer.class, name = "pageNum", value = "pageNum第几页"),
            @ApiImplicitParam(paramType = "query", dataTypeClass = Integer.class, name = "pageSize", value = "pageSize一页多少行"),
            @ApiImplicitParam(paramType = "query", dataTypeClass = String.class, name = "commentType", value = "评论类型"),
            @ApiImplicitParam(paramType = "query", dataTypeClass = String.class, name = "mainId", value = "评论主体id"),
    })
    public ResponseBean wxCommentList(@RequestParam(defaultValue = "1") Integer pageNum,
                                    @RequestParam(defaultValue = "10") Integer pageSize,
                                    @RequestParam String commentType,
                                    @RequestParam String mainId) {
        ResponseBean responseBean = new ResponseBean();
        responseBean = iCommentService.getWxCommentList(commentType, mainId, pageNum, pageSize);
        return responseBean;
    }

    @RequestMapping(value = "/wx/comment/add/{openid}", method = RequestMethod.POST)
    @ApiOperation(value = "微信小程序添加评论", notes = "微信小程序添加评论")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", dataTypeClass = String.class, name = "parameter", value = "commentType评论类型;mainId评论类型;parentId父级;commentContent评论内容;imgArray图片URL数组")
    })
    public ResponseBean addWxComment(@PathVariable("openid") String openid,@RequestBody String parameter) {
        ResponseBean responseBean = new ResponseBean();
        responseBean = iCommentService.addWxComment(openid,parameter);
        return responseBean;
    }


    @RequestMapping(value = "/comment/{commentId}", method = RequestMethod.GET)
    @ApiOperation(value = "获取评论详情", notes = "获取评论详情")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataTypeClass = String.class, name = "commentId",value = "评论id")
    })
    public ResponseBean selectCommentInfoId(@PathVariable("commentId") String commentId) {
        ResponseBean  responseBean = iCommentService.selectCommentInfoId(commentId);
        return responseBean;
    }
}
