package com.example.wholeestate.controller;


import com.example.wholeestate.common.base.BaseController;
import com.example.wholeestate.common.resp.ResponseBean;
import com.example.wholeestate.model.SysUser;
import com.example.wholeestate.service.ICustomerService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.propertyeditors.CustomDateEditor;
import org.springframework.web.bind.ServletRequestDataBinder;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * <p>
 *  用户
 * </p>
 *
 * @author weiximei
 * @since 2019-03-20
 */
@RestController
@RequestMapping("/")
@Api(value = "用户 API", description = "用户 API")
public class CustomerController extends BaseController {

    @Autowired
    private ICustomerService iCustomerService;

    /**
     * 自定义方法绑定请求参数的Date类型
     *
     * @param request
     * @param binder
     * @throws Exception
     */
    @InitBinder
    protected void initBinder(HttpServletRequest request, ServletRequestDataBinder binder) throws Exception {
        DateFormat df = new SimpleDateFormat("yyyy-MM-dd");
        CustomDateEditor editor = new CustomDateEditor(df, true);//true表示允许为空，false反之
        binder.registerCustomEditor(Date.class, editor);
    }

    @ApiOperation(value = "会员列表", notes = "会员列表")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "Query",dataType = "Integer",name = "pageNum",value = "pageNum:分页第几页" ),
            @ApiImplicitParam(paramType = "Query",dataType = "Integer",name = "pageSize",value = "pageSize:每页长度"),
            @ApiImplicitParam(paramType = "Query",dataType = "String",name = "phone",value = "phone:别名"),
            @ApiImplicitParam(paramType = "Query",dataType = "String",name = "name",value = "name:名字"),
            @ApiImplicitParam(paramType = "Query",dataType = "Date",name = "beginDate",value = "beginDate:开始时间"),
            @ApiImplicitParam(paramType = "Query",dataType = "Date",name = "endDate",value = "endDate:结束"),
            @ApiImplicitParam(paramType = "Query",dataType = "String",name = "cardNo",value = "cardNo:身份证")
    })
    @RequestMapping(value = "/customerList", method = RequestMethod.GET)
    public ResponseBean buildingList(@RequestParam(value = "pageNum", required = false)Integer pageNum,
                                     @RequestParam(value = "pageSize", required = false)Integer pageSize,
                                     @RequestParam(value = "name", required = false)String name,
                                     @RequestParam(value = "phone", required = false)String phone,
                                     @RequestParam(value = "cardNo", required = false)String cardNo,
                                     @RequestParam(value = "beginDate", required = false)Date beginDate,
                                     @RequestParam(value = "endDate", required = false)Date endDate){
        ResponseBean  responseBean = iCustomerService.customerList(pageNum,pageSize,phone,beginDate,endDate,name,cardNo);
        return responseBean;
    }

    @RequestMapping(value = "/customerSelectId/{id}", method = RequestMethod.GET)
    @ApiOperation(value = "会员详情", notes = "会员详情")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataTypeClass=String.class, name = "id", value = "会员id"),
    })
    public ResponseBean customerSelectId(@PathVariable(value = "id") String id, HttpSession session){
        ResponseBean  responseBean = iCustomerService.customerSelectId(id);
        return responseBean;
    }


}
